@@ -370,14 +370,14 @@ MyApplet.prototype = {
 
     showAddLauncherDialog: function(timestamp, launcher){
         if (launcher) {
-            let cl = APPLET_DIR.get_child('add-panel-launcher.py').get_path() + ' ';
+            let cl = APPLET_DIR.get_child('cinnamon-add-panel-launcher.py').get_path() + ' ';
             cl += '"' + launcher.getId() + '" ';
             cl += '"' + launcher.getAppname() + '" ';
             cl += '"' + launcher.getCommand() + '" ';
             cl += '"' + launcher.getIcon() + '"';
             Util.spawnCommandLine(cl);
         } else {
-            Util.spawnCommandLine(APPLET_DIR.get_child('add-panel-launcher.py').get_path());
+            Util.spawnCommandLine(APPLET_DIR.get_child('cinnamon-add-panel-launcher.py').get_path());
         }
     },
 
