@@ -109,7 +109,7 @@ cinnamon_app_system_init (CinnamonAppSystem *self)
   priv->apps_tree = gmenu_tree_new ("cinnamon-applications.menu", GMENU_TREE_FLAGS_INCLUDE_NODISPLAY);
   g_signal_connect (priv->apps_tree, "changed", G_CALLBACK (on_apps_tree_changed_cb), self);
 
-  priv->settings_tree = gmenu_tree_new ("cinnamon-settings.menu", 0);
+  priv->settings_tree = gmenu_tree_new ("cinnamon-settings.menu", GMENU_TREE_FLAGS_INCLUDE_NODISPLAY);
   g_signal_connect (priv->settings_tree, "changed", G_CALLBACK (on_settings_tree_changed_cb), self);
 
   on_apps_tree_changed_cb (priv->apps_tree, self);
@@ -490,6 +490,20 @@ cinnamon_app_system_get_default ()
   return instance;
 }
 
+gboolean
+case_insensitive_search (const char *key,
+                         const char *value,
+                         gpointer user_data)
+{
+  char *given_id = (char *) user_data;
+
+  if (g_ascii_strcasecmp(key, given_id) == 0) {
+    return TRUE;
+  } else {
+    return FALSE;
+  }
+}
+
 /**
  * cinnamon_app_system_lookup_app:
  *
@@ -501,7 +515,13 @@ CinnamonApp *
 cinnamon_app_system_lookup_app (CinnamonAppSystem   *self,
                              const char       *id)
 {
-  return g_hash_table_lookup (self->priv->id_to_app, id);
+  CinnamonApp *result;
+
+  result = g_hash_table_lookup (self->priv->id_to_app, id);
+  if (result == NULL) {
+    result = g_hash_table_find (self->priv->id_to_app, (GHRFunc) case_insensitive_search, id);
+  }
+  return result;
 }
 
 /**
@@ -515,7 +535,13 @@ CinnamonApp *
 cinnamon_app_system_lookup_settings_app (CinnamonAppSystem   *self,
                              const char       *id)
 {
-  return g_hash_table_lookup (self->priv->setting_id_to_app, id);
+  CinnamonApp *result;
+
+  result = g_hash_table_lookup (self->priv->setting_id_to_app, id);
+  if (result == NULL) {
+    result = g_hash_table_find (self->priv->setting_id_to_app, (GHRFunc) case_insensitive_search, id);
+  }
+  return result;
 }
 
 /**
@@ -614,6 +640,10 @@ cinnamon_app_system_lookup_heuristic_basename (CinnamonAppSystem *system,
   if (result != NULL)
     return result;
 
+  result = cinnamon_app_system_lookup_settings_app (system, name);
+  if (result != NULL)
+    return result;
+
   for (prefix = system->priv->known_vendor_prefixes; prefix; prefix = g_slist_next (prefix))
     {
       char *tmpid = g_strconcat ((char*)prefix->data, name, NULL);
